@@ -1,6 +1,7 @@
 from django.contrib.auth import get_user_model
 from django.core.exceptions import ValidationError
 from django.test import TestCase
+from django.utils import timezone
 
 from oauth_api.models import AccessToken, get_application_model
 
@@ -10,11 +11,12 @@ User = get_user_model()
 
 
 class TestModels(TestCase):
-    def setUp(self):
-        self.dev_user = User.objects.create_user('dev_user', 'dev_user@example.com', '1234')
+    @classmethod
+    def setUpTestData(cls):
+        cls.dev_user = User.objects.create_user('dev_user', 'dev_user@example.com', '1234')
 
     def test_allow_scopes(self):
-        app = Appliation(
+        app = Appliation.objects.create(
             name='Test App',
             redirect_uris='http://localhost http://example.com',
             user=self.dev_user,
@@ -22,10 +24,13 @@ class TestModels(TestCase):
             authorization_grant_type=Appliation.GRANT_AUTHORIZATION_CODE,
         )
 
-        access_token = AccessToken(
+        now = timezone.now()
+        expires = now + timezone.timedelta(days=7)
+        
+        access_token = AccessToken.objects.create(
             user=self.dev_user,
             scope='read write',
-            expires=0,
+            expires=expires,
             token='',
             application=app,
         )
@@ -36,6 +41,19 @@ class TestModels(TestCase):
         self.assertTrue(access_token.allow_scopes([]))
         self.assertFalse(access_token.allow_scopes(['read', 'invalid']))
 
+    def test_access_token_user_may_be_none(self):
+        app = Appliation.objects.create(
+            name='Test App',
+            redirect_uris='http://localhost http://example.com',
+            user=self.dev_user,
+            client_type=Appliation.CLIENT_CONFIDENTIAL,
+            authorization_grant_type=Appliation.GRANT_AUTHORIZATION_CODE,
+        )
+
+        access_token = AccessToken.objects.create(token='1234567890', application=app,
+                                                  expires=timezone.now())
+        self.assertIsNone(access_token.user)
+
     def test_default_redirect_uri(self):
         app = Appliation(
             name='Test App',
